@@ -19,7 +19,11 @@
 #include "../stfio.h"
 
 #if defined(WITH_BIOSIG2)
-    #include <biosig2.h>
+    #if defined(WITH_BIOSIGLITE)
+        #include "../../libbiosiglite/biosig4c++/biosig2.h"
+    #else
+        #include <biosig2.h>
+    #endif
     #if (BIOSIG_VERSION < 10506)
         #error libbiosig2 v1.5.6 or later is required
     #endif
@@ -606,7 +610,11 @@ bool stfio::exportBiosigFile(const std::string& fName, const Recording& Data, st
     double fs = 1.0/(PhysDimScale(pdc) * Data.GetXScale());
     biosig_set_samplerate(hdr, fs);
 
+#if (BIOSIG_VERSION < 10700)
     biosig_set_flags(hdr, 0, 0, 0);
+#else
+    biosig_reset_flag(hdr, BIOSIG_FLAG_COMPRESSION | BIOSIG_FLAG_UCAL | BIOSIG_FLAG_OVERFLOWDETECTION | BIOSIG_FLAG_ROW_BASED_CHANNELS );
+#endif
 
     size_t k, m, numberOfEvents=0;
     size_t NRec=0;	// corresponds to hdr->NRec
